#ifndef VIDMAG_H
#define VIDMAG_H

#include <QtWidgets/QMainWindow>
#include "ui_vidmag.h"
#include <QFileDialog>
#include <QMessageBox>
#include <VideoPlayer.h>
#include <QTime>
#include <VideoManager.hpp>
#include <qmenu.h>

namespace Ui {
	class Ui_VidMagClass;
}
class VidMag : public QMainWindow
{
	Q_OBJECT

public:
	explicit VidMag(QWidget *parent = 0);
	~VidMag();

	private slots:
	void updatePlayerUI(QImage img); //slot that the video frame signal connects to; displays the video frame in the UI
	
	//slots for the interaction with the UI elements
	void on_button_load_clicked();

	void on_button_play_clicked();

	void on_slider_video_sliderPressed();
	void on_slider_video_sliderReleased();
	void on_slider_video_sliderMoved(int position);

	void on_button_process_clicked();

	void on_button_mask_clicked();

	void on_button_delete_mask_clicked();

	void on_button_presets_load_clicked();
private:
	//UI, Player and Manager instances
	Ui_VidMagClass *ui;
	VideoPlayer* vidPlr;
	VideoManager* vidMgr;

	QString getFormattedTime(int timeInSeconds); //formats secs to (h:)mm:ss
	bool validateLineEdit(QLineEdit* lineEdit, bool format); //validates line edit text

	//handlers for mouse events; used for masking
	void mousePressEvent(QMouseEvent *e);
	void mouseMoveEvent(QMouseEvent *e);
	void mouseReleaseEvent(QMouseEvent *e);

	//transformations to video frame
	QPoint pointToPixmap(QPoint point);
	QPoint pixmapTl();

	//masking values
	bool selectionStarted;
	QRect selectionRect;
	bool masking;
	QRect pixmap_rect;
	QRubberBand* selection;
};

#endif // VIDMAG_H
